==> codota-sdk-java-1.0.8-sources.jar: com/codota/service/client/requests/GetArtifactDependenciesRequest.java <==
/*
 * Copyright (C) 2017 Codota
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.codota.service.client.requests;

import com.codota.service.client.requests.base.GetRequest;
import com.codota.service.connector.ServiceConnector;
import com.codota.service.model.DependencyInfo;
import org.jetbrains.annotations.NotNull;

import java.util.Arrays;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * Created by yahave on 3/3/16.
 * (C) Codota
 */
public class GetArtifactDependenciesRequest extends GetRequest<Map<String,DependencyInfo>> {

    private static final String FIND_DEP_ROUTE = "/api/codenav/artifact-dependencies";

    private static class FileDependency {
        String filepath;
        DependencyInfo dependencies;
    }


    public GetArtifactDependenciesRequest(ServiceConnector connector, String artifactName, String codePack, String token) {
        super(connector, connector.getBase() + FIND_DEP_ROUTE, null, buildProps(artifactName, codePack), token);

    }


    private static Map<String, String> buildProps(String artifactName, String codePack) {
        Map<String, String> props = new HashMap<String, String>();
        props.put("artifactName", artifactName);
        props.put("codePack", codePack);
        return props;
    }


    @NotNull
    public Map<String, DependencyInfo> parse(@NotNull String response) {
        try {
            Collection<FileDependency> fileDependencies = Arrays.asList(gson.fromJson(response, FileDependency[].class));
            Map<String, DependencyInfo> result = new HashMap<>();
            fileDependencies.forEach(dep -> result.put(dep.filepath, dep.dependencies));
            return result;
        } catch (IllegalStateException e) {
            System.err.println("json" + response);
            e.printStackTrace();
        } catch (com.google.gson.JsonSyntaxException e) {
            System.err.println("json" + response);
            e.printStackTrace();
        }

        return null;
    }

}

==> codota-sdk-java-1.0.10-sources.jar: com/codota/service/client/requests/GetArtifactDependenciesRequest.java <==
/*
 * Copyright (C) 2017 Codota
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.codota.service.client.requests;

import com.codota.service.client.requests.base.GetRequest;
import com.codota.service.connector.ServiceConnector;
import com.codota.service.model.DependencyInfo;
import org.jetbrains.annotations.NotNull;

import java.util.*;
import java.util.stream.Collectors;

/**
 * Created by yahave on 3/3/16.
 * (C) Codota
 */
public class GetArtifactDependenciesRequest extends GetRequest<List<Map.Entry<String, DependencyInfo>>> {

    private static final String FIND_DEP_ROUTE = "/api/codenav/artifact-dependencies";

    private static class FileDependency {
        String filepath;
        DependencyInfo dependencies;
    }


    public GetArtifactDependenciesRequest(ServiceConnector connector, String artifactName, String codePack, String token) {
        super(connector, connector.getBase() + FIND_DEP_ROUTE, null, buildProps(artifactName, codePack), token);

    }


    private static Map<String, String> buildProps(String artifactName, String codePack) {
        Map<String, String> props = new HashMap<String, String>();
        props.put("artifactName", artifactName);
        props.put("codePack", codePack);
        return props;
    }


    @NotNull
    public List<Map.Entry<String, DependencyInfo>> parse(@NotNull String response) {
        try {
            Collection<FileDependency> fileDependencies = Arrays.asList(gson.fromJson(response, FileDependency[].class));
            List<Map.Entry<String, DependencyInfo>> result = new ArrayList<>();
            fileDependencies.forEach(dep -> result.add(new AbstractMap.SimpleEntry<String, DependencyInfo>(dep.filepath, dep.dependencies)));
            return result;
        } catch (IllegalStateException e) {
            System.err.println("json" + response);
            e.printStackTrace();
        } catch (com.google.gson.JsonSyntaxException e) {
            System.err.println("json" + response);
            e.printStackTrace();
        }

        return null;
    }

}
